--[[
The ShellCommandHandler is a specific implementation to handle commands for 
the SpamFilter plugin. The ShellCommandHandler is used by the ShellCommand.
]]

ShellCommandHandler = class();

-- Initializes a new ShellCommandHandler instance
function ShellCommandHandler:Constructor(filterEngine)
	-- our spam filter engine
	self.Engine = filterEngine;
end

-- Returns true if the command is a valid known command
function ShellCommandHandler:ValidateCommand(command)
	command = string.lower(command);

	-- known commands
	if  command == "on"        or 
		command == "off"       or
		command == "debug on"  or command == "d on"  or
		command == "debug off" or command == "d off" or
		command == "trace on"  or command == "t on"  or
		command == "trace off" or command == "t off" or
		command == string.lower(Strings.HelpCommandName) then

		return true;
	end

	return false;
end

-- Executes the command
function ShellCommandHandler:ExecuteCommand(command)
	command = string.lower(command);
	
	if command == "on" then
		self.Engine:SetActive(true);
		return true;
	end
	
	if command == "off" then
		self.Engine:SetActive(false);
		return true;
	end

	if command == "debug on" or command == "d on" then
		self.Engine:SetDebug(true);
		return true;
	end
	
	if command == "debug off" or command == "d off" then
		self.Engine:SetDebug(false);
		return true;
	end
	
	if command == "trace on" or command == "t on" then
		self.Engine:SetTraceSpam(true);
		return true;
	end
	
	if command == "trace off" or command == "t off" then
		self.Engine:SetTraceSpam(false);
		return true;
	end

	if command == string.lower(Strings.HelpCommandName) then
		self:TextOut(Strings.CommandHelp);
		return true;
	end

	return false;
end

-- Called by the ShellCommand to display short help
function ShellCommandHandler:GetShortHelp()
	return "[on|off] | [debug|d] [on|off] | [trace|t] [on|off] | " .. string.lower(Strings.HelpCommandName);
end

function ShellCommandHandler:TextOut(text)
	Turbine.Shell.WriteLine("Command:> " .. text);
end

